@@ -4,8 +4,7 @@ import unittest
 import doctest
 import trytond.tests.test_tryton
 from trytond.tests.test_tryton import ModuleTestCase
-from trytond.tests.test_tryton import doctest_setup, doctest_teardown
-from trytond.tests.test_tryton import doctest_checker
+from trytond.tests.test_tryton import doctest_teardown, doctest_checker
 
 
 class AccountDunningLetterTestCase(ModuleTestCase):
@@ -18,7 +17,7 @@ def suite():
     suite.addTests(unittest.TestLoader().loadTestsFromTestCase(
         AccountDunningLetterTestCase))
     suite.addTests(doctest.DocFileSuite('scenario_account_dunning_letter.rst',
-            setUp=doctest_setup, tearDown=doctest_teardown, encoding='utf-8',
+            tearDown=doctest_teardown, encoding='utf-8',
             checker=doctest_checker,
             optionflags=doctest.REPORT_ONLY_FIRST_FAILURE))
     return suite
